Contribution guide
==================

We're always open to fixes and new features! Please open a PR for any changes
that you have and someone will review and merge it. If you're not up for
writing the code, open an issue for any problems or requests.

Bug fixes
---------

If you find a bug in "kafka-tools" we welcome patches to help fix the problem.

A few things to keep in mind when submitting bug fixes:

* Please include details on reproducing the bug
* Explain how your patch resolves the issue
* Test cases for the fix are extremely helpful
* Would your patch affect existing expected behaviors? For example, catching
  an exception may fix an issue for your code, but another caller may expect
  that exception in order to handle the error case differently.

Code guidelines
---------------

Please follow these Python best practices:

* Provide documentation for new or modified APIs
* Provide test cases for new or modified APIs
